aboutsummaryrefslogtreecommitdiffstats
path: root/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java
diff options
context:
space:
mode:
authorAdithya Abraham Philip <adithyaphilip@gmail.com>2015-06-01 17:43:00 +0530
committerAdithya Abraham Philip <adithyaphilip@gmail.com>2015-06-01 17:43:00 +0530
commit6bc40d12ad44c4170f10054fb8ea7d2c9459da35 (patch)
treea7b79e122d81bb3cd97b870ce38499e0778e9a0a /OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java
parent14a08361e52bcd8bd26b9b2b2b9690276b40ed42 (diff)
downloadopen-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.tar.gz
open-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.tar.bz2
open-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.zip
renamed KeychainIntentService to KeychainService
Diffstat (limited to 'OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java')
-rw-r--r--OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java b/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java
index 6dfa77d3f..130d22b37 100644
--- a/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java
+++ b/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/dialog/ProgressDialogFragment.java
@@ -34,7 +34,7 @@ import android.view.View.OnClickListener;
import android.widget.Button;
import org.sufficientlysecure.keychain.R;
-import org.sufficientlysecure.keychain.service.KeychainIntentService;
+import org.sufficientlysecure.keychain.service.KeychainService;
/**
* meant to be used
@@ -178,11 +178,11 @@ public class ProgressDialogFragment extends DialogFragment {
negative.setTextColor(Color.GRAY);
// send a cancel message. note that this message will be handled by
// KeychainIntentService.onStartCommand, which runs in this thread,
// not the service one, and will not queue up a command.
- Intent serviceIntent = new Intent(getActivity(), KeychainIntentService.class);
+ Intent serviceIntent = new Intent(getActivity(), KeychainService.class);
- serviceIntent.setAction(KeychainIntentService.ACTION_CANCEL);
+ serviceIntent.setAction(KeychainService.ACTION_CANCEL);
getActivity().startService(serviceIntent);
// Set the progress bar accordingly
@@ -178,11 +178,11 @@ public class ProgressDialogFragment extends DialogFragment {
negative.setTextColor(Color.GRAY);
// send a cancel message. note that this message will be handled by
- // KeychainIntentService.onStartCommand, which runs in this thread,
+ // KeychainService.onStartCommand, which runs in this thread,
// not the service one, and will not queue up a command.